@@ -1,6 +1,8 @@
 package Log::Contextual::Role::Router;
-$Log::Contextual::Role::Router::VERSION = '0.006005';
-# ABSTRACT: Abstract interface between loggers and logging code blocks
+use strict;
+use warnings;
+
+our $VERSION = '0.009001';
 
 use Moo::Role;
 
@@ -16,13 +18,15 @@ __END__
 
 =encoding UTF-8
 
+=for :stopwords Arthur Axel "fREW" Schmidt
+
 =head1 NAME
 
 Log::Contextual::Role::Router - Abstract interface between loggers and logging code blocks
 
 =head1 VERSION
 
-version 0.006005
+version 0.009001
 
 =head1 SYNOPSIS
 
@@ -36,34 +40,34 @@ version 0.006005
   has logger => (is => 'lazy');
 
   sub _build_logger {
-     return Log::Contextual::SimpleLogger->new({ levels_upto => 'debug' });
+    return Log::Contextual::SimpleLogger->new({ levels_upto => 'debug' });
   }
 
   sub before_import {
-     my ($self, %export_info) = @_;
-     my $exporter = $export_info{exporter};
-     my $target = $export_info{target};
-     print STDERR "Package '$target' will import from '$exporter'\n";
+    my ($self, %export_info) = @_;
+    my $exporter = $export_info{exporter};
+    my $target = $export_info{target};
+    print STDERR "Package '$target' will import from '$exporter'\n";
   }
 
   sub after_import {
-     my ($self, %export_info) = @_;
-     my $exporter = $export_info{exporter};
-     my $target = $export_info{target};
-     print STDERR "Package '$target' has imported from '$exporter'\n";
+    my ($self, %export_info) = @_;
+    my $exporter = $export_info{exporter};
+    my $target = $export_info{target};
+    print STDERR "Package '$target' has imported from '$exporter'\n";
   }
 
   sub handle_log_request {
-     my ($self, %message_info) = @_;
-     my $log_code_block = $message_info{message_sub};
-     my $args = $message_info{message_args};
-     my $log_level_name = $message_info{message_level};
-     my $logger = $self->logger;
-     my $is_active = $logger->can("is_${log_level_name}");
+    my ($self, %message_info) = @_;
+    my $log_code_block = $message_info{message_sub};
+    my $args = $message_info{message_args};
+    my $log_level_name = $message_info{message_level};
+    my $logger = $self->logger;
+    my $is_active = $logger->can("is_${log_level_name}");
 
-     return unless defined $is_active && $logger->$is_active;
-     my $log_message = $log_code_block->(@$args);
-     $logger->$log_level_name($log_message);
+    return unless defined $is_active && $logger->$is_active;
+    my $log_message = $log_code_block->(@$args);
+    $logger->$log_level_name($log_message);
   }
 
   package MyApp::Log::Contextual;
@@ -75,7 +79,7 @@ version 0.006005
 
   #This example router is a singleton
   sub router {
-     our $Router ||= MyApp::Log::Router->new
+    our $Router ||= MyApp::Log::Router->new
   }
 
   package main;
@@ -179,8 +183,8 @@ This is the name of the log level associated with the log event.
 
 =item message_sub
 
-This is the message generating code block associated with the log event passed as a subref. If
-the logger accepts the log request the router should execute the subref to create
+This is the message generating code block associated with the log event passed as a code reference. If
+the logger accepts the log request the router should execute the code reference to create
 the log message and then pass the message as a string to the logger.
 
 =item message_args
@@ -193,13 +197,22 @@ as well.
 
 =back
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/haarg/Log-Contextual/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2024 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
